#ifndef __HTTPSERVER_H
#define __HTTPSERVER_H

#include "filesys.h"
#include <ESP8266WebServer.h>


class HTTPServer {
private:
    bool configured = false;
    const int port;
    const char* rootDir;
    std::function<void ()> callbackFn;
 
    bool addRootFileHandler();
    bool formatFS() {
        return format_fs();
    }
    void listRoot() {
        ls(rootDir);
    }

public:
    ESP8266WebServer server;

    HTTPServer(const int _port, const char* _rootDir, std::function<void ()> fn) :
        port(_port), rootDir(_rootDir), callbackFn(fn)
    { }
    ~HTTPServer() 
    {
        server.stop();
    }

    bool start() {
        if(!mount_fs())
            return false;
        Serial.printf("LittleFS mounted => Starting Webserver on Port %d\n\r", this->port);
        server.begin(port);
        return true;
    }
    void handleClient() { 
        server.handleClient(); 
    }
};



#endif // __HTTPSERVER_H